<?php

namespace App\TestTools\Rhawn;

use App\Rhawn\Repositories\Eloquent\RhawnSordersRepositoryEloquent;
use App\Rhawn\Services\RhawnCustomerService;
use App\Support\Facades\SimpleLogs;
use Illuminate\Support\Facades\DB;

class RhawnToolsService
{
    public function __construct(\App\Rhawn\Services\RhawnOrdersService $rhawnOrdersService)
    {
        $this->rhawnOrdersService = $rhawnOrdersService;
        $this->rhawnCustomerService = app(RhawnCustomerService::class);
    }

    /**
     * 修改用户订单价格
     */
    public function updateCustomerOrdersPricesByDiscount($cusCode, $discount)
    {
        $customer = $this->rhawnCustomerService->checkCustomerExist($cusCode);
        if($customer){
            $rhawnOrderRepository = app(RhawnSordersRepositoryEloquent::class);
            $orderList = $rhawnOrderRepository->getOrdersListThroughtUserId($customer['cus_id'],1,1000);
            if($orderList) {
                $armedOrders = [];
                foreach ($orderList as $order) {
                    if ($order['so_review_status'] == 0) {
                        array_push($armedOrders, $order);
                    }
                }
                $connection = DB::connection($rhawnOrderRepository->getConnectionName());
                try {
                    $connection->beginTransaction();

                    //处理状态0的订单
                    if (count($armedOrders) > 0) {
                        foreach ($armedOrders as $order) {
                            $orderDetail = $this->rhawnOrdersService->getCustomerOrderItemsByOrderId($customer['cus_id'], $order['so_id']);
                            if ($orderDetail) {
                                foreach ($orderDetail as $detail) {
                                    $si_discount = 0;
                                    $si_amount = 0;
                                    if ($detail['p_id'] > 0) {
                                        $si_discount = round($detail['si_price'] * $discount);
                                        $si_amount = bcadd($detail['si_num'], $si_discount);
                                        $connection->table('soitems')
                                            ->where('si_id',$detail['si_id'])
                                            ->update([
                                                'si_discount' => $si_discount,
                                                'si_amount' => $si_amount
                                            ]);
                                    }
                                }
                                //更新订单总价
                                $total = $connection->table('soitems')
                                    ->where('so_id',$order['so_id'])
                                    ->select(DB::raw('sum(si_amount) as amount'))
                                    ->get();
                                var_dump($total);
                            }
                        }
                        $connection->commit();
                    }
                }catch(\Throwable $exception){
                    $connection->rollBack();
                    SimpleLogs::writeLog($exception->getMessage(),__CLASS__.':updateCustomerOrdersPricesByDiscount','error');
                }
            }
        }
    }
}
